.ifndef CONFIGURE_INC
.equ	CONFIGURE_INC=1

;***************************************************************************
;*
;* CONSTANTS
;*	Firmware Configuration
;*
;* DESCRIPTION
;*	This sections defines the firmware options.
;*
;***************************************************************************


;*********************
;* Firmware Revision *
;*********************

.equ	SW_MAJOR = '4'		; Major SW revision number
.equ	SW_MINOR = '0'		; Minor SW revision number

;********************
;* Software Options *
;********************

.equ	SUPPORT_HEALTH_CHECK = TRUE     ; If TRUE, healthcheck code is inserted (requires LED_USE=TRUE) 
.equ	SUPPORT_CHIP_ID      = TRUE	; If TRUE, inserts the chip ID in the last word of the flash
.equ	SUPPORT_BLOCK_CMD    = TRUE	; If TRUE, supports AVRprog block commands
.equ	SUPPORT_v_CMD 	     = TRUE	; If TRUE, supports the hardwware version command (not required for AVRprog, required for avrdude)
.equ	SUPPORT_BYTE_CMD     = TRUE	; If TRUE, supports the traditional memory commands 
					; not required for AVRprog if SUPPORT_BLOCK_CMD==TRUE ... 
					; ... required vor avrdude

;********************
;* Devices Supported*
;********************

.equ	S1200D	= 0x13
.equ	S2313A	= 0x20
.equ	S4414A	= 0x28
.equ	S4433A	= 0x30
.equ	S2333A	= 0x34
.equ	S8515A	= 0x38
.equ	m8515   = 0x3A 
.equ	m8515B	= 0x3B 
.equ	m103	= 0x41 ; obsolete
.equ	m603	= 0x42 ; obsolete 
.equ	m128	= 0x43 
.equ	m128B	= 0x44 
.equ	S2323A	= 0x48
.equ	S2343A	= 0x4C
.equ	tn11	= 0x50 
.equ	tn10	= 0x51 
.equ	tn12	= 0x55
.equ	tn15	= 0x56
.equ	tn19	= 0x58 
.equ	tn28	= 0x5C 
.equ	tn26	= 0x5E 
.equ	m161	= 0x60 
.equ	m161B	= 0x61 
.equ	m163	= 0x64 ; obsolete
.equ	m83	= 0x65 ; obsolete
.equ	m163B	= 0x66 ; obsolete	
.equ	m83B	= 0x67 ; obsolete
.equ	S8535	= 0x68 ; obsolete
.equ	m8535   = 0x6A 
.equ	m8535B	= 0x6B 
.equ	S4434	= 0x6C ; obsolete 
.equ	C8534	= 0x70 ; obsolete
.equ	C8544 	= 0x71 ; obsolete
.equ	m64	= 0x46 ; code unknown !!
.equ	m64B	= 0x47 ; code unknown !!
.equ	m32	= 0x72 
.equ	m32B	= 0x73 
.equ	m16	= 0x74 
.equ	m16B	= 0x75 
.equ	m8	= 0x76 
.equ	m8B	= 0x77 


;***************************************************************************
;*
;* CONSTANTS
;*	Hardware Configuration
;*
;* DESCRIPTION
;*	This sections describes the pin assignment and characteristics of 
;* 	the physical interfaces.
;*
;***************************************************************************


;*********************
;* Hardware Revision *
;*********************

.equ	HW_MAJOR = '1'		; Major HW revision number
.equ	HW_MINOR = '1'		; Minor HW revision number


;*******************
;* Target Settings *
;*******************

;.include "1200def.inc"		; Device
.include "2313def.inc"		; Device
.equ	CLK 	 = 4000000	; Clock Rate


;******************
;* LED Settings   *
;******************

.equ	LED_USE	    = TRUE	; if TRUE, external LED is supported
.equ	LED_DUAL    = TRUE	; if TRUE, the external LED is a dual-color LED
.equ	LED_BUG	    = TRUE 	; if TRUE, the LED commands accept an additonal parameter
.equ	LED_PIN	    = PINB	; Port number
.equ	LED_PORT    = PORTB	; Port number
.equ	LED_DDR	    = DDRB	; Port number
.equ	LED	    = 0		; Bit number
.equ	LEDH	    = 3		; Bit number


;*****************
;* SPI Settings  *
;*****************

.equ	SPI_BPS  = 800000	; Bit Rate
.equ	SPI_PIN  = PINB		; Port number
.equ	SPI_PORT = PORTB	; Port number
.equ	SPI_DDR  = DDRB		; Port number
.equ	RESET 	 = 4		; Bit number 
.equ	MOSI	 = 6		; Bit number 
.equ	MISO	 = 5		; Bit number 
.equ	SCK	 = 7		; Bit number 


;******************
;* UART Settings  *
;******************

;.equ	UART_BAUD   = 115200	; Bit  rate (19200/38400/115200)
.equ	UART_BAUD   = 19200	; Bit  rate
.equ	UART_SW	    = FALSE	; if TRUE, the UART is realized in Software
.equ	UART_RXSIZE = 16	; Receiver Buffer Size in bytes for block write command
.equ	UART_PIN    = PIND	; Port number
.equ	UART_PORT   = PORTD	; Port number
.equ	UART_DDR    = DDRD	; Port number
.equ	TXD 	    = 1		; Bit number 
.equ	RXD 	    = 0		; Bit number 

.endif
